@@ -24,6 +24,7 @@
 #include <boost/signal.hpp>
 
 #include <iosfwd>
+#include <string>
 #include <map>
 #include <utility>
 #include <vector>
@@ -217,6 +218,10 @@ public:
 	    child document)
 	 */
 	Buffer const * getMasterBuffer() const;
+	/** Get the document's master (or \c this if this is not a
+	    child document)
+	 */
+	Buffer * getMasterBuffer();
 
 	/// Is buffer read-only?
 	bool isReadonly() const;
@@ -249,6 +254,12 @@ public:
 
 	/// return all bibkeys from buffer and its childs
 	void fillWithBibKeys(std::vector<std::pair<std::string, std::string> > & keys) const;
+	/// Update the cache with all bibfiles in use (including bibfiles
+	/// of loaded child documents).
+	void updateBibfilesCache();
+	/// Return the cache with all bibfiles in use (including bibfiles
+	/// of loaded child documents).
+	std::vector<std::string> const & getBibfilesCache() const;
 	///
 	void getLabelList(std::vector<std::string> &) const;
 
@@ -332,7 +343,7 @@ public:
 	///
 	StableDocIterator getAnchor() const { return anchor_; }
 	///
-	void changeRefsIfUnique(std::string const & from, std::string const & to);
+	void changeRefsIfUnique(std::string const & from, std::string const & to, InsetBase::Code code);
 
 private:
 	/** Inserts a file into a document
@@ -352,6 +363,9 @@ private:
 	/// it's BufferView, this should be FIXED in future.
 	StableDocIterator cursor_;
 	StableDocIterator anchor_;
+	/// A cache for the bibfiles (including bibfiles of loaded child
+	/// documents), needed for appropriate update of natbib labels.
+	std::vector<std::string> bibfilesCache_;
 };
 
 #endif
