@@ -24,11 +24,17 @@ class QTocDialog : public QTocDialogBase {
 public:
 	QTocDialog(QToc * form);
 	~QTocDialog();
+	///
+	void enableButtons(bool enable = true);
 public slots:
 	void activate_adaptor(int);
 	void depth_adaptor(int);
 	void select_adaptor(QListViewItem *);
 	void update_adaptor();
+	void moveup_adaptor();
+	void movedn_adaptor();
+	void movein_adaptor();
+	void moveout_adaptor();
 protected:
 	void closeEvent(QCloseEvent * e);
 private:
