@@ -357,7 +357,15 @@ enum kb_action {
 	LFUN_BIBDB_ADD,
 	LFUN_BIBDB_DEL,
 	LFUN_INSERT_CITATION,
+	LFUN_OUTLINE_UP,                 // Vermeer 20060323
+	// 275
+	LFUN_OUTLINE_DOWN,
+	LFUN_OUTLINE_IN,
+	LFUN_OUTLINE_OUT,
 	LFUN_TOGGLE_COMPRESSION,         // bpeng 20060427
+	LFUN_INSET_DISSOLVE,             // jspitzm 20060807
+	// 280
+	LFUN_MATH_BIGDELIM,
 
 	LFUN_LASTACTION                  // end of the table
 };
