@@ -18,7 +18,7 @@
 class MathSplitInset : public MathGridInset {
 public:
 	///
-	explicit MathSplitInset(std::string const & name);
+	explicit MathSplitInset(std::string const & name, char valign = 'c');
 
 	///
 	void draw(PainterInfo & pi, int x, int y) const;
@@ -31,6 +31,8 @@ public:
 	///
 	void infoize(std::ostream & os) const;
 	///
+	void validate(LaTeXFeatures & features) const;
+	///
 	int defaultColSpace(col_type) { return 0; }
 	///
 	char defaultColAlign(col_type);
